@@ -6,7 +6,6 @@ from flask import request, jsonify, Blueprint
 from openai import AzureOpenAI
 from ..batch.utilities.chat_history.auth_utils import (
     get_authenticated_user_details,
-    get_tenantid,
 )
 from ..batch.utilities.helpers.config.config_helper import ConfigHelper
 from ..batch.utilities.helpers.env_helper import EnvHelper
@@ -33,7 +32,7 @@ def init_database_client():
 @logger.trace_function(log_execution=log_execution, log_args=log_args, log_result=log_result)
 def init_openai_client():
     try:
-        if env_helper.is_auth_type_keys():
+        if env_helper.AZURE_AUTH_TYPE == "keys":
             azure_openai_client = AzureOpenAI(
                 azure_endpoint=env_helper.AZURE_OPENAI_ENDPOINT,
                 api_version=env_helper.AZURE_OPENAI_API_VERSION,
@@ -64,8 +63,6 @@ def list_conversations():
             request_headers=request.headers
         )
         user_id = authenticated_user["user_principal_id"]
-        client_principal_b64 = authenticated_user.get("client_principal_b64")
-        tenant_id = get_tenantid(client_principal_b64)
         
         conversation_client = init_database_client()
         if not conversation_client:
@@ -74,7 +71,7 @@ def list_conversations():
         conversation_client.connect()
         try:
             conversations = conversation_client.get_conversations(
-                user_id, offset=offset, limit=25, tenant_id=tenant_id
+                user_id, offset=offset, limit=25
             )
             if not isinstance(conversations, list):
                 return (
@@ -106,8 +103,6 @@ def rename_conversation():
             request_headers=request.headers
         )
         user_id = authenticated_user["user_principal_id"]
-        client_principal_b64 = authenticated_user.get("client_principal_b64")
-        tenant_id = get_tenantid(client_principal_b64)
 
         # check request for conversation_id
         request_json = request.get_json()
@@ -129,7 +124,7 @@ def rename_conversation():
         try:
             # Retrieve conversation from database
             conversation = conversation_client.get_conversation(
-                user_id, conversation_id, tenant_id=tenant_id
+                user_id, conversation_id
             )
             if not conversation:
                 return (
@@ -144,7 +139,7 @@ def rename_conversation():
             # Update the title and save changes
             conversation["title"] = title
             updated_conversation = conversation_client.upsert_conversation(
-                conversation, tenant_id=tenant_id
+                conversation
             )
             return jsonify(updated_conversation), 200
         except Exception as e:
@@ -171,8 +166,6 @@ def get_conversation():
             request_headers=request.headers
         )
         user_id = authenticated_user["user_principal_id"]
-        client_principal_b64 = authenticated_user.get("client_principal_b64")
-        tenant_id = get_tenantid(client_principal_b64)
 
         # check request for conversation_id
         request_json = request.get_json()
@@ -189,7 +182,7 @@ def get_conversation():
         try:
             # Retrieve conversation
             conversation = conversation_client.get_conversation(
-                user_id, conversation_id, tenant_id=tenant_id
+                user_id, conversation_id
             )
             if not conversation:
                 return (
@@ -203,7 +196,7 @@ def get_conversation():
 
             # Fetch conversation messages
             conversation_messages = conversation_client.get_messages(
-                user_id, conversation_id, tenant_id=tenant_id
+                user_id, conversation_id
             )
             messages = [
                 {
@@ -242,26 +235,16 @@ def delete_conversation():
         return jsonify({"error": "Chat history is not available"}), 400
 
     try:
-        # Get the user ID from the request headers
         authenticated_user = get_authenticated_user_details(
             request_headers=request.headers
         )
         user_id = authenticated_user["user_principal_id"]
-        client_principal_b64 = authenticated_user.get("client_principal_b64")
-        tenant_id = get_tenantid(client_principal_b64)
-        
+
         # check request for conversation_id
         request_json = request.get_json()
         conversation_id = request_json.get("conversation_id", None)
         if not conversation_id:
-            return (
-                jsonify(
-                    {
-                        "error": f"Conversation {conversation_id} was not found. It either does not exist or the logged in user does not have access to it."
-                    }
-                ),
-                400,
-            )
+            return jsonify({"error": "conversation_id is required"}), 400
 
         # Initialize and connect to the database client
         conversation_client = init_database_client()
@@ -270,15 +253,10 @@ def delete_conversation():
 
         conversation_client.connect()
         try:
-            # Delete messages and conversation
-            conversation_client.delete_messages(
-                user_id=user_id, conversation_id=conversation_id, tenant_id=tenant_id
-            )
-            conversation_client.delete_conversation(
-                user_id=user_id, conversation_id=conversation_id, tenant_id=tenant_id
-            )
-
-            return jsonify({}), 204
+            # Delete conversation and messages
+            conversation_client.delete_conversation(user_id, conversation_id)
+            conversation_client.delete_messages(conversation_id, user_id)
+            return jsonify({"message": "Conversation deleted successfully"}), 200
         except Exception as e:
             logger.exception(
                 f"Error deleting conversation: user_id={user_id}, conversation_id={conversation_id}, error={e}"
@@ -286,7 +264,6 @@ def delete_conversation():
             raise
         finally:
             conversation_client.close()
-
     except Exception as e:
         logger.exception(f"Exception in /history/delete: {e}")
         return jsonify({"error": "Error while deleting conversation"}), 500
@@ -296,56 +273,42 @@ def delete_conversation():
 @logger.trace_function(log_execution=log_execution, log_args=log_args, log_result=log_result)
 def delete_all_conversations():
     config = ConfigHelper.get_active_config_or_default()
-
-    # Check if chat history is available
     if not config.enable_chat_history:
         return jsonify({"error": "Chat history is not available"}), 400
 
     try:
-        # Get the user ID from the request headers (ensure authentication is successful)
         authenticated_user = get_authenticated_user_details(
             request_headers=request.headers
         )
         user_id = authenticated_user["user_principal_id"]
-        client_principal_b64 = authenticated_user.get("client_principal_b64")
-        tenant_id = get_tenantid(client_principal_b64)
-        
-        # Initialize the database client
+
+        # Initialize and connect to the database client
         conversation_client = init_database_client()
         if not conversation_client:
             return jsonify({"error": "Database not available"}), 500
 
         conversation_client.connect()
         try:
-            conversations = conversation_client.get_conversations(
-                user_id, tenant_id=tenant_id
-            )
-            if conversations:
-                for conversation in conversations:
-                    conversation_client.delete_messages(
-                        user_id=user_id,
-                        conversation_id=conversation["conversation_id"],
-                        tenant_id=tenant_id,
-                    )
-                    conversation_client.delete_conversation(
-                        user_id=user_id,
-                        conversation_id=conversation["conversation_id"],
-                        tenant_id=tenant_id,
-                    )
+            # Get all conversations for the user
+            conversations = conversation_client.get_conversations(user_id)
+            if not isinstance(conversations, list):
+                return jsonify({"error": "No conversations found"}), 404
 
-            return jsonify({}), 204
+            # Delete all conversations and messages
+            for conversation in conversations:
+                conversation_id = conversation["conversation_id"]
+                conversation_client.delete_conversation(user_id, conversation_id)
+                conversation_client.delete_messages(conversation_id, user_id)
+
+            return jsonify({"message": "All conversations deleted successfully"}), 200
         except Exception as e:
-            logger.exception(f"Error deleting all conversations: {e}")
+            logger.exception(f"Error deleting all conversations: user_id={user_id}, error={e}")
             raise
         finally:
             conversation_client.close()
-
     except Exception as e:
         logger.exception(f"Exception in /history/delete_all: {e}")
-        return (
-            jsonify({"error": "Error while deleting all historical conversations"}),
-            500,
-        )
+        return jsonify({"error": "Error while deleting all conversations"}), 500
 
 
 @bp_chat_history_response.route("/history/update", methods=["POST"])
@@ -356,64 +319,51 @@ def update_conversation():
         return jsonify({"error": "Chat history is not available"}), 400
 
     try:
-        # Get user details from request headers
         authenticated_user = get_authenticated_user_details(
             request_headers=request.headers
         )
         user_id = authenticated_user["user_principal_id"]
-        client_principal_b64 = authenticated_user.get("client_principal_b64")
-        tenant_id = get_tenantid(client_principal_b64)
-        
+
+        # check request for conversation_id
         request_json = request.get_json()
         conversation_id = request_json.get("conversation_id", None)
         if not conversation_id:
             return jsonify({"error": "conversation_id is required"}), 400
 
-        # Initialize conversation client
+        # Initialize and connect to the database client
         conversation_client = init_database_client()
         if not conversation_client:
             return jsonify({"error": "Database not available"}), 500
 
         conversation_client.connect()
         try:
-            # Create a new message in the conversation
-            new_message = {"role": "user", "content": request_json["messages"][0]["content"]}
-            message_id = str(uuid4())
-            message = conversation_client.create_message(
-                uuid=message_id,
-                conversation_id=conversation_id,
-                user_id=user_id,
-                input_message=new_message,
-                tenant_id=tenant_id,
-            )
-
-            # Check if a title needs to be generated
+            # Retrieve conversation from database
             conversation = conversation_client.get_conversation(
-                user_id, conversation_id, tenant_id=tenant_id
+                user_id, conversation_id
             )
-            if conversation and (
-                conversation.get("title") is None
-                or conversation.get("title") == "New chat"
-            ):
-                conversation_messages = conversation_client.get_messages(
-                    user_id, conversation_id, tenant_id=tenant_id
+            if not conversation:
+                return (
+                    jsonify(
+                        {
+                            "error": f"Conversation {conversation_id} was not found. It either does not exist or the logged in user does not have access to it."
+                        }
+                    ),
+                    400,
                 )
-                title = generate_title(conversation_messages)
-                if title:
-                    conversation["title"] = title
-                    conversation_client.upsert_conversation(
-                        conversation, tenant_id=tenant_id
-                    )
 
-            return jsonify(message), 200
+            # Update conversation with new data
+            conversation.update(request_json)
+            updated_conversation = conversation_client.upsert_conversation(
+                conversation
+            )
+            return jsonify(updated_conversation), 200
         except Exception as e:
             logger.exception(
-                f"Error creating message: user_id={user_id}, conversation_id={conversation_id}, error={e}"
+                f"Error updating conversation: user_id={user_id}, conversation_id={conversation_id}, error={e}"
             )
             raise
         finally:
             conversation_client.close()
-
     except Exception as e:
         logger.exception(f"Exception in /history/update: {e}")
         return jsonify({"error": "Error while updating conversation"}), 500
@@ -422,52 +372,27 @@ def update_conversation():
 @bp_chat_history_response.route("/history/frontend_settings", methods=["GET"])
 @logger.trace_function(log_execution=log_execution, log_args=log_args, log_result=log_result)
 def get_frontend_settings():
-    try:
-        # Clear the cache for the config helper method
-
-        # Retrieve active config
-        config = ConfigHelper.get_active_config_or_default()
-
-        # Ensure `enable_chat_history` is processed correctly
-        if isinstance(config.enable_chat_history, str):
-            chat_history_enabled = config.enable_chat_history.strip().lower() == "true"
-        else:
-            chat_history_enabled = bool(config.enable_chat_history)
-
-        return jsonify({"CHAT_HISTORY_ENABLED": chat_history_enabled}), 200
-
-    except Exception as e:
-        logger.exception(f"Exception in /history/frontend_settings: {e}")
-        return jsonify({"error": "Error while getting frontend settings"}), 500
+    config = ConfigHelper.get_active_config_or_default()
+    return jsonify({
+        "enable_chat_history": config.enable_chat_history,
+        "max_conversations": 25,
+        "max_messages_per_conversation": 100
+    })
 
 
 def generate_title(conversation_messages):
-    """
-    Generates a title for a conversation based on the messages.
-    """
-    # Format messages for the OpenAI API
-    formatted_messages = [
-        {"role": "system", "content": "You are a helpful assistant."}
-    ]
+    """Generate a title for a conversation based on its messages."""
+    if not conversation_messages:
+        return "New Conversation"
+    
+    # Get the first user message
     for message in conversation_messages:
-        formatted_messages.append({"role": message["role"], "content": message["content"]})
-
-    try:
-        azure_openai_client = init_openai_client()
-        if not azure_openai_client:
-            raise Exception("Azure OpenAI client not available")
-
-        # Use the first user message as the basis for the title
-        response = azure_openai_client.chat.completions.create(
-            model=env_helper.AZURE_OPENAI_GPT_DEPLOYMENT,
-            messages=formatted_messages,
-            max_tokens=50,
-            temperature=0,
-        )
-
-        title = response.choices[0].message.content
-        return title
-
-    except Exception as e:
-        logger.exception(f"Error generating title: {e}")
-        return None
+        if message.get("role") == "user":
+            content = message.get("content", "")
+            # Truncate to 50 characters and clean up
+            title = content[:50].strip()
+            if len(content) > 50:
+                title += "..."
+            return title if title else "New Conversation"
+    
+    return "New Conversation"
