@@ -54,41 +54,25 @@ class AzurePostgresHelper:
         return self._create_search_client()
 
     @logger.trace_function(log_execution=log_execution, log_args=False, log_result=False)
-    def get_vector_store(self, embedding_array, tenant_id: str = None):
+    def get_vector_store(self, embedding_array):
         """
-        Fetches search indexes from PostgreSQL based on an embedding vector for a specific tenant.
+        Fetches search indexes from PostgreSQL based on an embedding vector.
         """
         conn = self.get_search_client()
         try:
             with conn.cursor(cursor_factory=RealDictCursor) as cur:
-                if tenant_id:
-                    cur.execute(
-                        """
-                        SELECT id, title, chunk, "offset", page_number, content, source
-                        FROM vector_store
-                        WHERE tenant_id = %s
-                        ORDER BY content_vector <=> %s::vector
-                        LIMIT %s
-                        """,
-                        (
-                            tenant_id,
-                            embedding_array,
-                            self.env_helper.AZURE_POSTGRES_SEARCH_TOP_K,
-                        ),
-                    )
-                else:
-                    cur.execute(
-                        """
-                        SELECT id, title, chunk, "offset", page_number, content, source
-                        FROM vector_store
-                        ORDER BY content_vector <=> %s::vector
-                        LIMIT %s
-                        """,
-                        (
-                            embedding_array,
-                            self.env_helper.AZURE_POSTGRES_SEARCH_TOP_K,
-                        ),
-                    )
+                cur.execute(
+                    """
+                    SELECT id, title, chunk, "offset", page_number, content, source
+                    FROM vector_store
+                    ORDER BY content_vector <=> %s::vector
+                    LIMIT %s
+                    """,
+                    (
+                        embedding_array,
+                        self.env_helper.AZURE_POSTGRES_SEARCH_TOP_K,
+                    ),
+                )
                 search_results = cur.fetchall()
                 logger.info(f"Retrieved {len(search_results)} search results.")
                 return search_results
@@ -120,7 +104,6 @@ class AzurePostgresHelper:
                         d["source"],
                         d["metadata"],
                         d["content_vector"],
-                        d["tenant_id"],
                     )
                     for d in documents_to_upload
                 ]
@@ -129,7 +112,7 @@ class AzurePostgresHelper:
                 query = """
                     INSERT INTO vector_store (
                         id, title, chunk, chunk_id, "offset", page_number,
-                        content, source, metadata, content_vector, tenant_id
+                        content, source, metadata, content_vector
                     ) VALUES %s
                 """
                 execute_values(cur, query, data_to_insert)
@@ -153,9 +136,9 @@ class AzurePostgresHelper:
                 conn.close()
 
     @logger.trace_function(log_execution=log_execution, log_args=False, log_result=log_result)
-    def get_files(self, tenant_id: str = None):
+    def get_files(self):
         """
-        Fetches distinct titles from the PostgreSQL database for a specific tenant.
+        Fetches distinct titles from the PostgreSQL database.
 
         Returns:
             list[dict] or None: A list of dictionaries (each with a single key 'title')
@@ -165,22 +148,13 @@ class AzurePostgresHelper:
         try:
             # Using a cursor to execute the query
             with conn.cursor(cursor_factory=RealDictCursor) as cursor:
-                if tenant_id:
-                    query = """
-                        SELECT id, title
-                        FROM vector_store
-                        WHERE title IS NOT NULL AND tenant_id = %s
-                        ORDER BY title;
-                    """
-                    cursor.execute(query, (tenant_id,))
-                else:
-                    query = """
-                        SELECT id, title
-                        FROM vector_store
-                        WHERE title IS NOT NULL
-                        ORDER BY title;
-                    """
-                    cursor.execute(query)
+                query = """
+                    SELECT id, title
+                    FROM vector_store
+                    WHERE title IS NOT NULL
+                    ORDER BY title;
+                """
+                cursor.execute(query)
                 # Fetch all results
                 results = cursor.fetchall()
                 # Return results or None if empty
@@ -197,13 +171,12 @@ class AzurePostgresHelper:
                 conn.close()
 
     @logger.trace_function(log_execution=log_execution, log_args=log_args, log_result=log_result)
-    def delete_documents(self, ids_to_delete, tenant_id: str = None):
+    def delete_documents(self, ids_to_delete):
         """
-        Deletes documents from the PostgreSQL database based on the provided ids for a specific tenant.
+        Deletes documents from the PostgreSQL database based on the provided ids.
 
         Args:
             ids_to_delete (list): A list of document IDs to delete.
-            tenant_id (str): The ID of the tenant to which the documents belong.
 
         Returns:
             int: The number of deleted rows.
@@ -216,28 +189,16 @@ class AzurePostgresHelper:
 
             # Using a cursor to execute the query
             with conn.cursor() as cursor:
-                if tenant_id:
-                    # Construct the DELETE query with the list of ids_to_delete and tenant_id
-                    query = """
-                        DELETE FROM vector_store
-                        WHERE id = ANY(%s) AND tenant_id = %s
-                    """
-                    # Extract the 'id' values from the list of dictionaries (ids_to_delete)
-                    ids_to_delete_values = [item["id"] for item in ids_to_delete]
+                # Construct the DELETE query with the list of ids_to_delete only
+                query = """
+                    DELETE FROM vector_store
+                    WHERE id = ANY(%s)
+                """
+                # Extract the 'id' values from the list of dictionaries (ids_to_delete)
+                ids_to_delete_values = [item["id"] for item in ids_to_delete]
 
-                    # Execute the query, passing the list of IDs and tenant_id as parameters
-                    cursor.execute(query, (ids_to_delete_values, tenant_id))
-                else:
-                    # Construct the DELETE query with the list of ids_to_delete only
-                    query = """
-                        DELETE FROM vector_store
-                        WHERE id = ANY(%s)
-                    """
-                    # Extract the 'id' values from the list of dictionaries (ids_to_delete)
-                    ids_to_delete_values = [item["id"] for item in ids_to_delete]
-
-                    # Execute the query, passing the list of IDs as parameters
-                    cursor.execute(query, (ids_to_delete_values,))
+                # Execute the query, passing the list of IDs as parameters
+                cursor.execute(query, (ids_to_delete_values,))
 
                 # Commit the transaction
                 conn.commit()
@@ -270,13 +231,12 @@ class AzurePostgresHelper:
                 conn.close()
 
     @logger.trace_function(log_execution=log_execution, log_args=log_args, log_result=False)
-    def perform_search(self, title, tenant_id: str = None):
+    def perform_search(self, title):
         """
-        Fetches search results from PostgreSQL based on the title and tenant.
+        Fetches search results from PostgreSQL based on the title.
 
         Args:
             title (str): The title to search for
-            tenant_id (str): The ID of the tenant to filter by. If None, searches across all tenants.
 
         Returns:
             list[dict] or None: Search results or None if no results found
@@ -285,26 +245,15 @@ class AzurePostgresHelper:
         conn = self.get_search_client()
         try:
             with conn.cursor(cursor_factory=RealDictCursor) as cur:
-                if tenant_id:
-                    # Execute query to fetch title, content, and metadata with tenant filtering
-                    cur.execute(
-                        """
-                        SELECT title, content, metadata
-                        FROM vector_store
-                        WHERE title = %s AND tenant_id = %s
-                        """,
-                        (title, tenant_id),
-                    )
-                else:
-                    # Execute query to fetch title, content, and metadata without tenant filtering
-                    cur.execute(
-                        """
-                        SELECT title, content, metadata
-                        FROM vector_store
-                        WHERE title = %s
-                        """,
-                        (title,),
-                    )
+                # Execute query to fetch title, content, and metadata without tenant filtering
+                cur.execute(
+                    """
+                    SELECT title, content, metadata
+                    FROM vector_store
+                    WHERE title = %s
+                    """,
+                    (title,),
+                )
                 results = cur.fetchall()  # Fetch all matching results
                 logger.info(f"Retrieved {len(results)} search result(s).")
                 return results
@@ -317,12 +266,9 @@ class AzurePostgresHelper:
                 conn.close()
 
     @logger.trace_function(log_execution=log_execution, log_args=log_args, log_result=log_result)
-    def get_unique_files(self, tenant_id: str = None):
+    def get_unique_files(self):
         """
-        Fetches unique titles from PostgreSQL for a specific tenant.
-
-        Args:
-            tenant_id (str): The ID of the tenant to filter by. If None, returns all unique titles.
+        Fetches unique titles from PostgreSQL.
 
         Returns:
             list[dict] or None: A list of dictionaries (each with a single key 'title')
@@ -332,24 +278,13 @@ class AzurePostgresHelper:
         conn = self.get_search_client()
         try:
             with conn.cursor(cursor_factory=RealDictCursor) as cur:
-                if tenant_id:
-                    # Execute query to fetch distinct titles for specific tenant
-                    cur.execute(
-                        """
-                        SELECT DISTINCT title
-                        FROM vector_store
-                        WHERE tenant_id = %s
-                        """,
-                        (tenant_id,),
-                    )
-                else:
-                    # Execute query to fetch distinct titles for all tenants
-                    cur.execute(
-                        """
-                        SELECT DISTINCT title
-                        FROM vector_store
-                        """
-                    )
+                # Execute query to fetch distinct titles for all tenants
+                cur.execute(
+                    """
+                    SELECT DISTINCT title
+                    FROM vector_store
+                    """
+                )
                 results = cur.fetchall()  # Fetch all results as RealDictRow objects
                 logger.info(f"Retrieved {len(results)} unique title(s).")
                 return results
@@ -389,20 +324,3 @@ class AzurePostgresHelper:
             # Only close connection if it exists and is open
             if conn and conn.closed == 0:
                 conn.close()
-
-    @logger.trace_function(log_execution=log_execution, log_args=log_args, log_result=log_result)
-    def store_with_lightrag(self, documents_to_upload):
-        """
-        Stores documents using LightRAG for enhanced vector and text storage capabilities.
-        """
-        conn = self.get_search_client()
-        try:
-            self.lightrag_helper.store_documents(documents_to_upload, conn)
-            logger.info(f"Stored {len(documents_to_upload)} documents using LightRAG.")
-        except Exception as e:
-            logger.error(f"Error storing documents with LightRAG: {e}")
-            raise
-        finally:
-            # Only close connection if it exists and is open
-            if conn and conn.closed == 0:
-                conn.close()
