@@ -22,7 +22,7 @@ class AzurePostgresHandler(SearchHandlerBase):
 
 
     @logger.trace_function(log_execution=log_execution, log_args=False, log_result=False)
-    def query_search(self, question, tenant_id: str = None) -> List[SourceDocument]:
+    def query_search(self, question) -> List[SourceDocument]:
         logger.info(f"Starting query search for question: {question}")
         user_input = question
         query_embedding = self.azure_postgres_helper.llm_helper.generate_embeddings(
@@ -32,7 +32,7 @@ class AzurePostgresHandler(SearchHandlerBase):
         embedding_array = np.array(query_embedding).tolist()
 
         search_results = self.azure_postgres_helper.get_vector_store(
-            embedding_array, tenant_id
+            embedding_array
         )
 
         source_documents = self._convert_to_source_documents(search_results)
@@ -56,9 +56,7 @@ class AzurePostgresHandler(SearchHandlerBase):
         return source_documents
 
 
-    @logger.trace_function(log_execution=log_execution, log_args=log_args, log_result=False)
-    def create_search_client(self):
-        return self.azure_postgres_helper.get_search_client()
+    # Note: create_search_client method removed - PostgreSQL implementation doesn't use Azure Search client
 
 
     @logger.trace_function(log_execution=log_execution, log_args=False, log_result=False)
@@ -69,9 +67,9 @@ class AzurePostgresHandler(SearchHandlerBase):
         return self.azure_postgres_helper.create_vector_store(documents_to_upload)
 
     @logger.trace_function(log_execution=log_execution, log_args=log_args, log_result=False)
-    def perform_search(self, filename, tenant_id: str = None):
+    def perform_search(self, filename):
         logger.info(f"Performing search for filename: {filename}")
-        return self.azure_postgres_helper.perform_search(filename, tenant_id)
+        return self.azure_postgres_helper.perform_search(filename)
 
     @logger.trace_function(log_execution=log_execution, log_args=False, log_result=False)
     def process_results(self, results):
@@ -86,8 +84,8 @@ class AzurePostgresHandler(SearchHandlerBase):
         return data
 
     @logger.trace_function(log_execution=log_execution, log_args=log_args, log_result=False)
-    def get_files(self, tenant_id: str = None):
-        results = self.azure_postgres_helper.get_files(tenant_id)
+    def get_files(self):
+        results = self.azure_postgres_helper.get_files()
         if results is None or len(results) == 0:
             logger.info("No files found.")
             return []
@@ -110,14 +108,14 @@ class AzurePostgresHandler(SearchHandlerBase):
 
 
     @logger.trace_function(log_execution=log_execution, log_args=log_args, log_result=log_result)
-    def delete_files(self, files, tenant_id: str = None):
+    def delete_files(self, files):
         ids_to_delete = []
         files_to_delete = []
 
         for filename, ids in files.items():
             files_to_delete.append(filename)
             ids_to_delete += [{"id": id} for id in ids]
-        self.azure_postgres_helper.delete_documents(ids_to_delete, tenant_id)
+        self.azure_postgres_helper.delete_documents(ids_to_delete)
 
         return ", ".join(files_to_delete)
 
@@ -127,17 +125,17 @@ class AzurePostgresHandler(SearchHandlerBase):
         return self.azure_postgres_helper.search_by_blob_url(blob_url)
 
     @logger.trace_function(log_execution=log_execution, log_args=log_args, log_result=log_result)
-    def delete_from_index(self, blob_url, tenant_id: str = None) -> None:
+    def delete_from_index(self, blob_url) -> None:
         logger.info(f"Deleting from index for blob URL: {blob_url}")
         documents = self.search_by_blob_url(blob_url)
         if documents is None or len(documents) == 0:
             logger.info("No documents found for blob URL.")
             return
         files_to_delete = self.output_results(documents)
-        self.delete_files(files_to_delete, tenant_id)
+        self.delete_files(files_to_delete)
 
     @logger.trace_function(log_execution=log_execution, log_args=log_args, log_result=log_result)
-    def get_unique_files(self, tenant_id: str = None):
-        results = self.azure_postgres_helper.get_unique_files(tenant_id)
+    def get_unique_files(self):
+        results = self.azure_postgres_helper.get_unique_files()
         unique_titles = [row["title"] for row in results]
         return unique_titles
